import { useEditor } from "@/modules/editor";
import Quill from "quill";
import "quill/dist/quill.bubble.css";
import { defineComponent, onMounted, ref, watchEffect } from "vue";
import { string } from "vue-types";
import { View } from "./View";


export const Textarea = defineComponent({
  props: {
    value: string().def(""),
  },
  emits: ["update:value"],
  setup(props, { emit }) {
    const domRef = ref();
    const { store } = useEditor();
    let quill: Quill | undefined = undefined;
    onMounted(() => {
      quill = new Quill(domRef.value, {
        theme: "bubble",
      });
      store.isEditMode && quill.disable();
      quill.on("text-change", () => {
        emit("update:value", quill?.getContents());
      });
      try {
        quill.setContents(JSON.parse(props.value));
      } catch (error) {
        quill.setText("初始化数据失败");
      }
    });
    watchEffect(() => {
      if (store.isEditMode) {
        quill?.enable();
      } else {
        quill?.disable();
      }
    });
    return () => (
      <View>
        <div class="w-1/1 h-1/1" ref={domRef}></div>
      </View>
    );
  },
});
