import { useEditor } from "@/modules/editor";
import { HotKeyCtrl } from "@/modules/editor/controllers/HotKeyCtrl";
import { defineUI } from "queenjs";
import { onUnmounted } from "vue";
import { Container, Draggable } from "vue-dndrop";

export default defineUI({
  setup() {
    const editor = useEditor();
    const { store, components, actions } = editor;

    const hotKeyCtrl = new HotKeyCtrl(editor);
    hotKeyCtrl.init();
    onUnmounted(() => {
      hotKeyCtrl.destroy();
    });

    return () => {
      const { content } = store.designData;
      return (
        <div class="h-1/1 text-center">
          <div
            class="inline-block w-375px h-750px overflow-y-auto scrollbar"
            style={store.designData.pageStyle}
          >
            {store.isEditMode ? (
              <Container
                onDrop={(e: any) =>
                  actions.moveComp(e.removedIndex, e.addedIndex)
                }
              >
                {content.map((d) => {
                  const Comp = components.CompUI[d.compKey];
                  return (
                    <Draggable key={d.id}>
                      <Comp
                        class="draggable-item"
                        data-id={d.id}
                        {...(d.props || {})}
                        style={d.style}
                        v-model={[d.value, "value"]}
                      />
                    </Draggable>
                  );
                })}
              </Container>
            ) : (
              content.map((d) => {
                const Comp = components.CompUI[d.compKey];
                return (
                  <Comp
                    key={d.id}
                    data-id={d.id}
                    {...(d.props || {})}
                    style={d.style}
                    v-model={[d.value, "value"]}
                  />
                );
              })
            )}
          </div>
        </div>
      );
    };
  },
});
