import { css, cx } from "@linaria/core";
import { IconDelete } from "@queenjs/icons";
import { Image, View } from "@queenjs/ui";
import { defineComponent } from "vue";
import { any, string } from "vue-types";

export default defineComponent({
  props: {
    record: any(),
    use: string<"show" | "select">().def("show"),
  },
  emits: ["delete", "select", "download"],
  setup(props, { emit }) {
    return () => {
      const { record, use } = props;
      // console.log("record: ", record);

      return (
        <div class={cx(itemStyles, "relative")}>
          {use == "show" && (
            <div class="waiting absolute inset-0 z-2 flex items-center justify-center text-white hidden">
              生成中…
            </div>
          )}
          <div class="absolute inset-0 flex items-center justify-center z-2 opacity-0 hover:opacity-100 transition-all  text-white">
            {use == "show" && (
              <IconDelete
                class="icon_del absolute right-5px top-5px p-3px rounded-2px text-14px cursor-pointer"
                onClick={() => emit("delete")}
              />
            )}
            {use == "show" ? (
              <div
                class="btn_circle rounded-1/2 text-center w-56px leading-56px cursor-pointer"
                onClick={() => emit("download")}
              >
                下载
              </div>
            ) : (
              <div
                class="btn_circle  rounded-1/2 text-center w-56px leading-56px cursor-pointer"
                onClick={() => emit("select")}
              >
                使用
              </div>
            )}
          </div>
          <View ratio={1.4} class="overflow-hidden">
            <Image class="h-1/1 w-1/1" src={record?.thumbnail?.url} />
          </View>
        </div>
      );
    };
  },
});

const itemStyles = css`
  .btn_circle {
    background-color: rgba(0, 0, 0, 0.7);
    &:hover {
      background-color: rgba(0, 0, 0, 0.8);
    }
    &:not(:first-child) {
      margin-left: 10px;
    }
  }
  .icon_del {
    background-color: rgba(0, 0, 0, 0.5);
    &:hover {
      background-color: rgba(0, 0, 0, 0.6);
    }
  }
  .waiting {
    background-color: rgba(0, 0, 0, 0.2);
  }
`;
