import { useResource } from "@/modules/resource";
import { css, cx } from "@linaria/core";
import { Button, Space } from "ant-design-vue";
import { defineComponent, onMounted, reactive } from "vue";
import AssetsList from "../components/AssetsList";
import MaterialTemplateModal from "./components/MaterialTemplateModal";

const materialType = [
  { name: "视频", key: "video" },
  { name: "图片", key: "image" },
];

export default defineComponent({
  setup() {
    const resource = useResource();

    const state = reactive({
      type: "video",
    });

    const showModal = (type: string) => {
      resource.showModal(<MaterialTemplateModal type={type} />, {
        title: `${type === "image" ? "图片" : "视频"}模板中心`,
        width: "1000px",
      });
    };

    onMounted(() => {
      resource.controls.materialListCtrl.state.query = { type: state.type };
      // resource.controls.materialListCtrl.loadPage(1);
    });

    return () => {
      return (
        <div class={rootStyles}>
          <h3 class="text-22px">我的素材</h3>
          <div class="flex items-center justify-between mt-20px">
            <div class="filter">
              <Space size={60}>
                {materialType.map((d) => (
                  <span
                    key={d.key}
                    onClick={() => (state.type = d.key)}
                    class={cx(
                      state.type == d.key && "active",
                      "cursor-pointer btn_tab"
                    )}
                  >
                    {d.name}
                  </span>
                ))}
              </Space>
            </div>
            <div>
              <Button
                ghost
                type="primary"
                onClick={resource.actions.uploadMaterial}
              >
                上传素材
              </Button>
              <Button
                ghost
                type="primary"
                class="ml-25px"
                onClick={() => showModal("image")}
              >
                生成图片
              </Button>
              <Button
                ghost
                type="primary"
                class="ml-15px"
                onClick={() => showModal("video")}
              >
                生成视频
              </Button>
            </div>
          </div>
          <AssetsList
            columns={6}
            class="mt-30px"
            control={resource.controls.materialListCtrl}
            item={(record: any) => (
              <resource.components.MaterialItem
                record={record}
                onDelete={() => resource.actions.deleteMaterial(record)}
                onDownload={() => resource.actions.downloadMaterial(record)}
              />
            )}
          />
        </div>
      );
    };
  },
});

const rootStyles = css`
  .btn_tab {
    padding: 3px 5px;
    &:hover,
    &.active {
      color: @inf-primary-color;
    }
  }
`;
